@@ -1,29 +1,36 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-2001 by Solar Designer
+ *
+ * A public domain version of this code, with reentrant and crypt(3)
+ * interfaces added, but optimizations specific to password cracking
+ * removed, is available at:
+ *
+ *	http://www.openwall.com/crypt/
  *
  * This implementation is compatible with OpenBSD bcrypt.c (version 2a)
  * by Niels Provos <provos@physnet.uni-hamburg.de>, and uses some of his
  * ideas. The password hashing algorithm was designed by David Mazieres
- * <dm@lcs.mit.edu>. Some of the tricks in BF_ROUND might be inspired by
- * Eric Young's Blowfish library (I can't be sure if I would think of
- * something if I hadn't seen his code) -- SD.
+ * <dm@lcs.mit.edu>.
+ *
+ * There's a paper on the algorithm that explains its design decisions:
+ *
+ *	http://www.usenix.org/events/usenix99/provos.html
+ *
+ * Some of the tricks in BF_ROUND might be inspired by Eric Young's
+ * Blowfish library (I can't be sure if I would think of something if I
+ * hadn't seen his code).
  */
 
 #include <stdlib.h>
 #include <string.h>
 
 #include "arch.h"
+#include "common.h"
 #include "BF_std.h"
 
 BF_binary BF_out;
 
-/*
- * Magic IV for 64 Blowfish encryptions that we do at the end.
- */
-static char BF_magic_b[24] = "OrpheanBeholderScryDoubt";
-static BF_binary BF_magic_w;
-
 /* Number of Blowfish rounds, this is also hardcoded into a few places */
 #define BF_N				16
 
@@ -34,21 +41,30 @@ struct BF_ctx {
 	BF_key P;
 };
 
-#if !BF_SCALE
-#define BF_INDEX(S, i) \
-	(*((BF_word *)(((unsigned char *)S) + (i))))
-#endif
-
 /* Current Blowfish context */
 #if BF_ASM
 extern
 #else
 static
 #endif
-struct BF_ctx BF_current;
+struct BF_ctx CC_CACHE_ALIGN BF_current;
 
 /* Current Blowfish key */
-static BF_key BF_exp_key, BF_init_key;
+static BF_key CC_CACHE_ALIGN BF_exp_key;
+#if defined(__linux__) && defined(__sparc__)
+static BF_key BF_init_key;
+#else
+static BF_key CC_CACHE_ALIGN BF_init_key;
+#endif
+
+/*
+ * Magic IV for 64 Blowfish encryptions that we do at the end.
+ * The string is "OrpheanBeholderScryDoubt" on big-endian.
+ */
+static BF_word BF_magic_w[6] = {
+	0x4F727068, 0x65616E42, 0x65686F6C,
+	0x64657253, 0x63727944, 0x6F756274
+};
 
 /*
  * P-box and S-box tables initialized with digits of Pi.
@@ -325,6 +341,20 @@ static struct BF_ctx BF_init_state = {
 	}
 };
 
+/*
+ * Same charset, different order -- can't use the common.c table here.
+ */
+unsigned char BF_atoi64[0x80] = {
+	64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
+	64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64,
+	64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 0, 1,
+	54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 64, 64, 64, 64, 64,
+	64, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16,
+	17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 64, 64, 64, 64, 64,
+	64, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42,
+	43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 64, 64, 64, 64, 64
+};
+
 #if ARCH_LITTLE_ENDIAN
 
 static void BF_swap(BF_word *x, int count)
@@ -344,12 +374,6 @@ static void BF_swap(BF_word *x, int count)
 
 #endif
 
-void BF_std_init()
-{
-	memcpy(BF_magic_w, BF_magic_b, sizeof(BF_magic_w));
-	BF_swap(BF_magic_w, 6);
-}
-
 #if BF_SCALE
 /* Architectures which can shift addresses left by 2 bits with no extra cost */
 #define BF_ROUND(L, R, N) \
@@ -369,6 +393,8 @@ void BF_std_init()
 	R ^= tmp3;
 #else
 /* Architectures with no complicated addressing modes supported */
+#define BF_INDEX(S, i) \
+	(*((BF_word *)(((unsigned char *)S) + (i))))
 #define BF_ROUND(L, R, N) \
 	tmp1 = L & 0xFF; \
 	tmp1 <<= 2; \
@@ -415,7 +441,7 @@ void BF_std_init()
 
 #if BF_ASM
 
-extern void BF_body();
+extern void (*BF_body)(void);
 
 #else
 
@@ -556,7 +582,7 @@ void BF_std_crypt(BF_salt salt)
 	BF_out[1] = R;
 }
 
-void BF_std_crypt_exact()
+void BF_std_crypt_exact(void)
 {
 	BF_word L, R;
 	BF_word tmp1, tmp2, tmp3, tmp4;
@@ -579,61 +605,38 @@ void BF_std_crypt_exact()
 	BF_out[5] &= ~(BF_word)0xFF;
 }
 
-/*
- * Standard charset, but non-standard order, so we can't use the table
- * generated in common.c here.
- */
-static unsigned char BF_atoi64[0x80] =
-{
-	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-	0, 0, 0, 0, 0, 0, 0, 1, 54, 55,
-	56, 57, 58, 59, 60, 61, 62, 63, 0, 0,
-	0, 0, 0, 0, 0, 2, 3, 4, 5, 6,
-	7, 8, 9, 10, 11, 12, 13, 14, 15, 16,
-	17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27,
-	0, 0, 0, 0, 0, 0, 28, 29, 30,
-	31, 32, 33, 34, 35, 36, 37, 38, 39, 40,
-	41, 42, 43, 44, 45, 46, 47, 48, 49, 50,
-	51, 52, 53, 0, 0, 0, 0, 0
-};
-
 /*
  * I'm not doing any error checking in the routines below since the
  * ciphertext should have already been checked to be fmt_BF.valid().
  */
 
-static void BF_decode(void *buffer, int length, char *data)
+static void BF_decode(BF_word *dst, char *src, int size)
 {
-	unsigned char *dptr = (unsigned char *)buffer;
-	unsigned char *end = (unsigned char *)buffer + length;
-	char *sptr = data;
-	unsigned char c1, c2, c3, c4;
-
-	while (dptr < end) {
-		c1 = BF_atoi64[(ARCH_INDEX)*sptr++];
-		c2 = BF_atoi64[(ARCH_INDEX)*sptr++];
+	unsigned char *dptr = (unsigned char *)dst;
+	unsigned char *end = dptr + size;
+	unsigned char *sptr = (unsigned char *)src;
+	unsigned int c1, c2, c3, c4;
 
+	do {
+		c1 = BF_atoi64[ARCH_INDEX(*sptr++)];
+		c2 = BF_atoi64[ARCH_INDEX(*sptr++)];
 		*dptr++ = (c1 << 2) | ((c2 & 0x30) >> 4);
 		if (dptr >= end) break;
 
-		c3 = BF_atoi64[(ARCH_INDEX)*sptr++];
-
+		c3 = BF_atoi64[ARCH_INDEX(*sptr++)];
 		*dptr++ = ((c2 & 0x0F) << 4) | ((c3 & 0x3C) >> 2);
 		if (dptr >= end) break;
 
-		c4 = BF_atoi64[(ARCH_INDEX)*sptr++];
+		c4 = BF_atoi64[ARCH_INDEX(*sptr++)];
 		*dptr++ = ((c3 & 0x03) << 6) | c4;
-	}
+	} while (dptr < end);
 }
 
 BF_word *BF_std_get_salt(char *ciphertext)
 {
 	static BF_salt salt;
 
-	BF_decode(salt, 16, &ciphertext[7]);
+	BF_decode(salt, &ciphertext[7], 16);
 	BF_swap(salt, 4);
 
 	salt[4] = (BF_word)1 << atoi(&ciphertext[4]);
@@ -645,9 +648,9 @@ BF_word *BF_std_get_binary(char *ciphertext)
 {
 	static BF_binary binary;
 
-	BF_decode(binary, 23, &ciphertext[29]);
+	binary[5] = 0;
+	BF_decode(binary, &ciphertext[29], 23);
 	BF_swap(binary, 6);
-
 	binary[5] &= ~(BF_word)0xFF;
 
 	return binary;
