@@ -1,12 +1,20 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-99 by Solar Designer
  */
 
 /*
  * Benchmark to detect the best algorithm for a particular architecture.
  */
 
+#ifdef __ultrix__
+#define __POSIX
+#define _POSIX_SOURCE
+#endif
+
+#ifdef _SCO_C_DIALECT
+#include <limits.h>
+#endif
 #include <stdio.h>
 #include <time.h>
 
