@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-2002 by Solar Designer
  */
 
 #include <string.h>
@@ -27,7 +27,7 @@ static struct fmt_params crk_params;
 static struct fmt_methods crk_methods;
 static int crk_key_index, crk_last_key;
 static void *crk_last_salt;
-static void (*crk_fix_state)();
+static void (*crk_fix_state)(void);
 static struct db_keys *crk_guesses;
 static int64 *crk_timestamps;
 static char crk_stdout_key[PLAINTEXT_BUFFER_SIZE];
@@ -36,11 +36,11 @@ static void crk_dummy_set_salt(void *salt)
 {
 }
 
-static void crk_dummy_fix_state()
+static void crk_dummy_fix_state(void)
 {
 }
 
-static void crk_init_salt()
+static void crk_init_salt(void)
 {
 	if (!crk_db->salts->next) {
 		crk_methods.set_salt(crk_db->salts->salt);
@@ -48,14 +48,15 @@ static void crk_init_salt()
 	}
 }
 
-void crk_init(struct db_main *db, void (*fix_state)(),
+void crk_init(struct db_main *db, void (*fix_state)(void),
 	struct db_keys *guesses)
 {
+	char *where;
 	size_t size;
 
 	if (db->loaded)
-	if (fmt_self_test(db->format)) {
-		fprintf(stderr, "Self test failed\n");
+	if ((where = fmt_self_test(db->format))) {
+		fprintf(stderr, "Self test failed (%s)\n", where);
 		error();
 	}
 
@@ -105,7 +106,7 @@ static int crk_process_guess(struct db_salt *salt, struct db_password *pw,
 	crk_db->guess_count++;
 	status.guess_count++;
 
-	if (crk_guesses) {
+	if (crk_guesses && !dupe) {
 		strnfcpy(crk_guesses->ptr, key, crk_params.plaintext_length);
 		crk_guesses->ptr += crk_params.plaintext_length;
 		crk_guesses->count++;
@@ -142,7 +143,7 @@ static int crk_process_guess(struct db_salt *salt, struct db_password *pw,
 	return 0;
 }
 
-static int crk_process_event()
+static int crk_process_event(void)
 {
 	event_pending = 0;
 
@@ -168,11 +169,11 @@ static int crk_password_loop(struct db_salt *salt)
 	sig_timer_emu_tick();
 #endif
 
+	idle_yield();
+
 	if (event_pending)
 	if (crk_process_event()) return 1;
 
-	idle_yield(0);
-
 	crk_methods.crypt_all(crk_key_index);
 
 	status_update_crypts(salt->count * crk_key_index);
@@ -204,7 +205,7 @@ static int crk_password_loop(struct db_salt *salt)
 	return 0;
 }
 
-static int crk_salt_loop()
+static int crk_salt_loop(void)
 {
 	struct db_salt *salt;
 
@@ -218,6 +219,8 @@ static int crk_salt_loop()
 	crk_last_salt = NULL;
 	crk_fix_state();
 
+	crk_methods.clear_keys();
+
 	return 0;
 }
 
@@ -265,6 +268,8 @@ int crk_process_salt(struct db_salt *salt)
 	count = salt->keys->count;
 	index = 0;
 
+	crk_methods.clear_keys();
+
 	while (count--) {
 		strnzcpy(key, ptr, crk_params.plaintext_length + 1);
 		ptr += crk_params.plaintext_length;
@@ -281,7 +286,7 @@ int crk_process_salt(struct db_salt *salt)
 	return 0;
 }
 
-char *crk_get_key1()
+char *crk_get_key1(void)
 {
 	if (crk_db->loaded)
 		return crk_methods.get_key(0);
@@ -289,7 +294,7 @@ char *crk_get_key1()
 		return crk_stdout_key;
 }
 
-char *crk_get_key2()
+char *crk_get_key2(void)
 {
 	if (crk_key_index > 1)
 		return crk_methods.get_key(crk_key_index - 1);
@@ -300,7 +305,7 @@ char *crk_get_key2()
 		return NULL;
 }
 
-void crk_done()
+void crk_done(void)
 {
 	if (crk_db->loaded) {
 		if (crk_key_index && crk_db->salts && !event_abort)
