@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-2001 by Solar Designer
  */
 
 #include <stdio.h>
@@ -28,6 +28,7 @@ typedef char (*char2_table)
 typedef char (*chars_table)
 	[CHARSET_SIZE + 1][CHARSET_SIZE + 1][CHARSET_SIZE + 1];
 
+static int rec_compat;
 static int rec_entry;
 static int rec_numbers[CHARSET_LENGTH];
 
@@ -38,17 +39,26 @@ static void save_state(FILE *file)
 {
 	int pos;
 
-	fprintf(file, "%d\n", rec_entry);
+	fprintf(file, "%d\n%d\n%d\n", rec_entry, rec_compat, CHARSET_LENGTH);
 	for (pos = 0; pos < CHARSET_LENGTH; pos++)
 		fprintf(file, "%d\n", rec_numbers[pos]);
 }
 
 static int restore_state(FILE *file)
 {
+	int length;
 	int pos;
 
 	if (fscanf(file, "%d\n", &rec_entry) != 1) return 1;
-	for (pos = 0; pos < CHARSET_LENGTH; pos++) {
+	rec_compat = 1;
+	length = CHARSET_LENGTH;
+	if (rec_version >= 2) {
+		if (fscanf(file, "%d\n%d\n", &rec_compat, &length) != 2)
+			return 1;
+		if ((unsigned int)rec_compat > 1) return 1;
+		if ((unsigned int)length > CHARSET_LENGTH) return 1;
+	}
+	for (pos = 0; pos < length; pos++) {
 		if (fscanf(file, "%d\n", &rec_numbers[pos]) != 1) return 1;
 		if ((unsigned int)rec_numbers[pos] >= CHARSET_SIZE) return 1;
 	}
@@ -56,7 +66,7 @@ static int restore_state(FILE *file)
 	return 0;
 }
 
-static void fix_state()
+static void fix_state(void)
 {
 	rec_entry = entry;
 	memcpy(rec_numbers, numbers, sizeof(rec_numbers));
@@ -164,11 +174,11 @@ static void expand(char *dst, char *src, int size)
 	memset(present, 0, sizeof(present));
 	while (*dptr) {
 		if (--count <= 1) return;
-		present[((ARCH_INDEX)*dptr++) - CHARSET_MIN] = 1;
+		present[ARCH_INDEX(*dptr++) - CHARSET_MIN] = 1;
 	}
 
 	while (*sptr)
-	if (!present[(ARCH_INDEX)*sptr - CHARSET_MIN]) {
+	if (!present[ARCH_INDEX(*sptr) - CHARSET_MIN]) {
 		*dptr++ = *sptr++;
 		if (--count <= 1) break;
 	} else
@@ -208,36 +218,86 @@ static void inc_new_count(unsigned int length, int count,
 static int inc_key_loop(int length, int fixed, int count,
 	char *char1, char2_table char2, chars_table *chars)
 {
-	char key[PLAINTEXT_BUFFER_SIZE];
+	char key_i[PLAINTEXT_BUFFER_SIZE];
+	char key_e[PLAINTEXT_BUFFER_SIZE];
+	char *key;
+	char *chars_cache;
+	int numbers_cache;
 	int pos;
 
-	key[length + 1] = 0;
+	key_i[length + 1] = 0;
 	numbers[fixed] = count;
 
-	do {
-		key[0] = char1[numbers[0]];
+	chars_cache = NULL;
+
+update_all:
+	pos = 0;
+update_ending:
+	if (pos < 2) {
+		if (pos == 0)
+			key_i[0] = char1[numbers[0]];
 		if (length)
-			key[1] = (*char2)[key[0] - CHARSET_MIN][numbers[1]];
-		for (pos = 2; pos <= length; pos++)
-			key[pos] = (*chars[pos - 2])
-				[(ARCH_INDEX)key[pos - 2] - CHARSET_MIN]
-				[(ARCH_INDEX)key[pos - 1] - CHARSET_MIN]
-				[numbers[pos]];
+			key_i[1] = (*char2)[key_i[0] - CHARSET_MIN][numbers[1]];
+		pos = 2;
+	}
+	while (pos < length) {
+		key_i[pos] = (*chars[pos - 2])
+			[ARCH_INDEX(key_i[pos - 2]) - CHARSET_MIN]
+			[ARCH_INDEX(key_i[pos - 1]) - CHARSET_MIN]
+			[numbers[pos]];
+		pos++;
+	}
+	numbers_cache = numbers[length];
+	if (pos == length) {
+		chars_cache = (*chars[pos - 2])
+			[ARCH_INDEX(key_i[pos - 2]) - CHARSET_MIN]
+			[ARCH_INDEX(key_i[pos - 1]) - CHARSET_MIN];
+update_last:
+		key_i[length] = chars_cache[numbers_cache];
+	}
 
-		if (ext_filter(key))
-		if (crk_process_key(key)) return 1;
+	key = key_i;
+	if (!ext_mode || !f_filter || ext_filter_body(key_i, key = key_e))
+	if (crk_process_key(key)) return 1;
 
-		if (length) {
-			pos = 0;
-			do {
-				if (pos == fixed) continue;
-				if (++numbers[pos] <= count -
-					((pos < fixed) ? 1 : 0)) break;
-				numbers[pos] = 0;
-			} while (++pos <= length);
-		} else
-			if (++numbers[0] <= count) pos = 0; else break;
-	} while (pos <= length);
+	if (rec_compat) goto compat;
+
+	pos = length;
+	if (fixed < length) {
+		if (++numbers_cache <= count) {
+			if (length >= 2) goto update_last;
+			numbers[length] = numbers_cache;
+			goto update_ending;
+		}
+		numbers[pos--] = 0;
+		while (pos > fixed) {
+			if (++numbers[pos] <= count) goto update_ending;
+			numbers[pos--] = 0;
+		}
+	}
+	while (pos-- > 0) {
+		if (++numbers[pos] < count) goto update_ending;
+		numbers[pos] = 0;
+	}
+
+	return 0;
+
+compat:
+	pos = 0;
+	if (fixed) {
+		if (++numbers[0] < count) goto update_all;
+		if (!length && numbers[0] <= count) goto update_all;
+		numbers[0] = 0;
+		pos = 1;
+		while (pos < fixed) {
+			if (++numbers[pos] < count) goto update_all;
+			numbers[pos++] = 0;
+		}
+	}
+	while (++pos <= length) {
+		if (++numbers[pos] <= count) goto update_all;
+		numbers[pos] = 0;
+	}
 
 	return 0;
 }
@@ -306,7 +366,7 @@ void do_incremental_crack(struct db_main *db, char *mode)
 
 	if (max_count < 0) max_count = CHARSET_SIZE; else
 	if ((unsigned int)max_count > real_count)
-		fprintf(stderr,"Warning: only %d characters available\n",
+		fprintf(stderr, "Warning: only %d characters available\n",
 			real_count);
 
 	if (header->length >= 2)
@@ -316,6 +376,7 @@ void do_incremental_crack(struct db_main *db, char *mode)
 	for (pos = 0; pos < (int)header->length - 2; pos++)
 		chars[pos] = (chars_table)mem_alloc(sizeof(*chars[0]));
 
+	rec_compat = 0;
 	rec_entry = 0;
 	memset(rec_numbers, 0, sizeof(rec_numbers));
 
