@@ -1,9 +1,10 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-2002 by Solar Designer
  */
 
 #include <stdio.h>
+#include <unistd.h>
 #include <string.h>
 #include <stdlib.h>
 #include <sys/stat.h>
@@ -16,7 +17,6 @@
 #include "list.h"
 #include "tty.h"
 #include "signals.h"
-#include "idle.h"
 #include "common.h"
 #include "formats.h"
 #include "loader.h"
@@ -33,7 +33,7 @@
 #include "batch.h"
 
 #if CPU_DETECT
-extern int CPU_detect();
+extern int CPU_detect(void);
 #endif
 
 extern struct fmt_main fmt_DES, fmt_BSDI, fmt_MD5, fmt_BF;
@@ -54,7 +54,7 @@ static void john_register_one(struct fmt_main *format)
 	fmt_register(format);
 }
 
-static void john_register_all()
+static void john_register_all(void)
 {
 	if (options.format) strlwr(options.format);
 
@@ -71,7 +71,7 @@ static void john_register_all()
 	}
 }
 
-static void john_load()
+static void john_load(void)
 {
 	struct list_entry *current;
 
@@ -172,6 +172,13 @@ static void john_init(int argc, char **argv)
 #if CPU_DETECT
 	if (!CPU_detect()) {
 #if CPU_REQ
+#if CPU_FALLBACK
+#if defined(__DJGPP__) || defined(__CYGWIN32__)
+#error CPU_FALLBACK is incompatible with the current DOS and Win32 code
+#endif
+		execv(JOHN_SYSTEMWIDE_EXEC "/" CPU_FALLBACK_BINARY, argv);
+		perror("execv");
+#endif
 		fprintf(stderr, "Sorry, %s is required\n", CPU_NAME);
 		error();
 #endif
@@ -179,19 +186,26 @@ static void john_init(int argc, char **argv)
 #endif
 
 	path_init(argv);
-	cfg_init(CFG_NAME);
+
+#if JOHN_SYSTEMWIDE
+	cfg_init(CFG_PRIVATE_FULL_NAME, 1);
+	cfg_init(CFG_PRIVATE_ALT_NAME, 1);
+#endif
+	cfg_init(CFG_FULL_NAME, 1);
+	cfg_init(CFG_ALT_NAME, 0);
+
 	status_init(NULL, 1);
 	opt_init(argc, argv);
 
 	john_register_all();
 	common_init();
 
-	sig_init(idle_yield);
+	sig_init();
 
 	john_load();
 }
 
-static void john_run()
+static void john_run(void)
 {
 	if (options.flags & FLG_TEST_CHK)
 		benchmark_all();
@@ -225,7 +239,7 @@ static void john_run()
 	}
 }
 
-static void john_done()
+static void john_done(void)
 {
 	path_done();
 
@@ -259,14 +273,6 @@ int main(int argc, char **argv)
 		name[strlen(name) - 4] = 0;
 #endif
 
-	if (!strcmp(name, "john")) {
-		john_init(argc, argv);
-		john_run();
-		john_done();
-
-		return 0;
-	}
-
 	if (!strcmp(name, "unshadow"))
 		return unshadow(argc, argv);
 
@@ -276,6 +282,9 @@ int main(int argc, char **argv)
 	if (!strcmp(name, "unique"))
 		return unique(argc, argv);
 
-	fprintf(stderr, "Sorry, I can't find myself\n");
-	return 1;
+	john_init(argc, argv);
+	john_run();
+	john_done();
+
+	return 0;
 }
