@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-2000 by Solar Designer
  */
 
 #include <stdio.h>
@@ -29,7 +29,7 @@
  * Word separator characters for ldr_split_words(), used on GECOS fields.
  */
 #define issep \
-	"!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~\177\377"
+	"!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~\177"
 
 static char issep_map[0x100];
 static int issep_initialized = 0;
@@ -65,7 +65,7 @@ static void read_file(struct db_main *db, char *name, int flags,
 	if (fclose(file)) pexit("fclose");
 }
 
-static void ldr_init_issep()
+static void ldr_init_issep(void)
 {
 	char *pos;
 
@@ -75,7 +75,7 @@ static void ldr_init_issep()
 
 	memset(issep_map, 1, 33);
 	for (pos = issep; *pos; pos++)
-		issep_map[(ARCH_INDEX)*pos] = 1;
+		issep_map[ARCH_INDEX(*pos)] = 1;
 
 	issep_initialized = 1;
 }
@@ -246,11 +246,11 @@ static void ldr_split_string(struct list_main *dst, char *src)
 	pos = src;
 	do {
 		word = pos;
-		while (*word && issep_map[(ARCH_INDEX)*word]) word++;
+		while (*word && issep_map[ARCH_INDEX(*word)]) word++;
 		if (!*word) break;
 
 		pos = word;
-		while (!issep_map[(ARCH_INDEX)*pos]) pos++;
+		while (!issep_map[ARCH_INDEX(*pos)]) pos++;
 		if (*pos) *pos++ = 0;
 
 		list_add_unique(dst, word);
@@ -340,8 +340,7 @@ static void ldr_load_pw_line(struct db_main *db, char *line)
 		if (!current_salt) {
 			last_salt = db->salt_hash[salt_hash];
 			current_salt = db->salt_hash[salt_hash] =
-				mem_alloc_tiny(sizeof(struct db_salt),
-				MEM_ALIGN_WORD);
+				mem_alloc_tiny(salt_size, MEM_ALIGN_WORD);
 			current_salt->next = last_salt;
 
 			current_salt->salt = mem_alloc_copy(
@@ -541,6 +540,8 @@ static void ldr_init_hash(struct db_main *db)
 		for (size = 2; size >= 0; size--)
 		if (current->count >= password_hash_thresholds[size]) break;
 
+		if ((db->format->params.flags & FMT_BS) && !size) size = -1;
+
 		if (size >= 0 && mem_saving_level < 2) {
 			current->hash = mem_alloc_tiny(
 				password_hash_sizes[size] *
