@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-99 by Solar Designer
  */
 
 /*
@@ -15,7 +15,7 @@
 /*
  * Exit on error. Terminates the process with non-zero exit status.
  */
-extern void error();
+extern void error(void);
 
 /*
  * Similar to perror(), but supports formatted output, and calls error().
@@ -35,24 +35,24 @@ extern int write_loop(int fd, char *buffer, int count);
 
 /*
  * Similar to fgets(), but doesn't leave the newline character in the buffer,
- * and skips to the end of long lines. Handles both UNIX and DOS style text
+ * and skips to the end of long lines. Handles both Unix and DOS style text
  * files correctly.
  */
 extern char *fgetl(char *s, int size, FILE *stream);
 
 /*
- * Similar to strncpy(), but terminates with only one null if there's room
- * instead of null padding to the supplied size like strncpy() does.
+ * Similar to strncpy(), but terminates with only one NUL if there's room
+ * instead of padding to the supplied size like strncpy() does.
  */
 extern char *strnfcpy(char *dst, char *src, int size);
 
 /*
- * Similar to the above, but always null terminates the string.
+ * Similar to the above, but always NUL terminates the string.
  */
 extern char *strnzcpy(char *dst, char *src, int size);
 
 /*
- * Similar to strncat(), but total buffer size is supplied, and always null
+ * Similar to strncat(), but total buffer size is supplied, and always NUL
  * terminates the string.
  */
 extern char *strnzcat(char *dst, char *src, int size);
