@@ -1,12 +1,13 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-2002 by Solar Designer
  */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
+#include "arch.h"
 #include "misc.h"
 #include "params.h"
 #include "memory.h"
@@ -66,9 +67,18 @@ static struct opt_entry opt_list[] = {
 	{NULL}
 };
 
+#if DES_BS
+/* nonstd.c and parts of x86-mmx.S aren't mine */
+#define JOHN_COPYRIGHT \
+	"Solar Designer and others"
+#else
+#define JOHN_COPYRIGHT \
+	"Solar Designer"
+#endif
+
 #define JOHN_USAGE \
-"\nJohn the Ripper  Version " JOHN_VERSION \
-"  Copyright (c) 1996-98 by Solar Designer\n" \
+"John the Ripper password cracker, version " JOHN_VERSION "\n" \
+"Copyright (c) 1996-2002 by " JOHN_COPYRIGHT "\n" \
 "\n" \
 "Usage: %s [OPTIONS] [PASSWORD-FILES]\n" \
 "-single                   \"single crack\" mode\n" \
