@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-2002 by Solar Designer
  */
 
 /*
@@ -15,17 +15,32 @@
 /*
  * John's version number.
  */
-#define JOHN_VERSION			"1.6"
+#define JOHN_VERSION			"1.6.32"
 
 /*
- * Crash recovery file format version number.
+ * Is this a system-wide installation? *BSD ports and Linux distributions
+ * will probably want to set this to 1 for their builds of John.
+ */
+#ifndef JOHN_SYSTEMWIDE
+#define JOHN_SYSTEMWIDE			0
+#endif
+
+#if JOHN_SYSTEMWIDE
+#define JOHN_SYSTEMWIDE_EXEC		"/usr/libexec/john"
+#define JOHN_SYSTEMWIDE_HOME		"/usr/share/john"
+#define JOHN_PRIVATE_HOME		"~/.john"
+#endif
+
+/*
+ * Crash recovery file format version strings.
  */
 #define RECOVERY_VERSION_0		"REC0"
 #define RECOVERY_VERSION_1		"REC1"
-#define RECOVERY_VERSION_CURRENT	RECOVERY_VERSION_1
+#define RECOVERY_VERSION_2		"REC2"
+#define RECOVERY_VERSION_CURRENT	RECOVERY_VERSION_2
 
 /*
- * Charset file format version number.
+ * Charset file format version string.
  */
 #define CHARSET_VERSION			"CHR1"
 
@@ -52,10 +67,18 @@
 /*
  * File names.
  */
-#define LOG_NAME			"~/john.pot"
-#define CFG_NAME			"~/john.ini"
-#define RECOVERY_NAME			"~/restore"
-#define WORDLIST_NAME			"~/password.lst"
+#define CFG_FULL_NAME			"$JOHN/john.conf"
+#define CFG_ALT_NAME			"$JOHN/john.ini"
+#if JOHN_SYSTEMWIDE
+#define CFG_PRIVATE_FULL_NAME		JOHN_PRIVATE_HOME "/john.conf"
+#define CFG_PRIVATE_ALT_NAME		JOHN_PRIVATE_HOME "/john.ini"
+#define LOG_NAME			JOHN_PRIVATE_HOME "/john.pot"
+#define RECOVERY_NAME			JOHN_PRIVATE_HOME "/restore"
+#else
+#define LOG_NAME			"$JOHN/john.pot"
+#define RECOVERY_NAME			"$JOHN/restore"
+#endif
+#define WORDLIST_NAME			"$JOHN/password.lst"
 
 /*
  * Configuration file section names.
