@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-2001 by Solar Designer
  */
 
 #include <stdio.h>
@@ -28,6 +28,7 @@ extern int ftruncate(int fd, size_t length);
 #include "recovery.h"
 
 char *rec_name = RECOVERY_NAME;
+int rec_version = 0;
 int rec_argc = 0;
 char **rec_argv;
 
@@ -37,7 +38,7 @@ static struct db_main *rec_db;
 static void (*rec_save_mode)(FILE *file);
 
 #if defined(LOCK_EX) && OS_FLOCK
-static void rec_lock()
+static void rec_lock(void)
 {
 	if (flock(rec_fd, LOCK_EX | LOCK_NB)) {
 		if (errno == EWOULDBLOCK) {
@@ -68,7 +69,7 @@ void rec_init(struct db_main *db, void (*save_mode)(FILE *file))
 	rec_save_mode = save_mode;
 }
 
-void rec_save()
+void rec_save(void)
 {
 	int save_format;
 	long size;
@@ -142,7 +143,6 @@ static void rec_format_error(char *fn)
 void rec_restore_args(int lock)
 {
 	char line[LINE_BUFFER_SIZE];
-	int version;
 	int index, argc;
 	char **argv;
 	char *save_rec_name;
@@ -155,8 +155,9 @@ void rec_restore_args(int lock)
 
 	if (!fgetl(line, sizeof(line), rec_file)) rec_format_error("fgets");
 
-	version = 0;
-	if (!strcmp(line, RECOVERY_VERSION_1)) version = 1; else
+	rec_version = 0;
+	if (!strcmp(line, RECOVERY_VERSION_2)) rec_version = 2; else
+	if (!strcmp(line, RECOVERY_VERSION_1)) rec_version = 1; else
 	if (strcmp(line, RECOVERY_VERSION_0)) rec_format_error("fgets");
 
 	if (fscanf(rec_file, "%d\n", &argc) != 1) rec_format_error("fscanf");
@@ -183,7 +184,7 @@ void rec_restore_args(int lock)
 		&status.crypts.hi) != 4) rec_format_error("fscanf");
 	if (!status_restored_time) status_restored_time = 1;
 
-	if (version == 0) {
+	if (rec_version == 0) {
 		status.pass = 0;
 		status.progress = -1;
 	} else
