@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-99 by Solar Designer
  */
 
 #include <stdio.h>
@@ -9,7 +9,6 @@
 #include "arch.h"
 #include "misc.h"
 #include "params.h"
-#include "path.h"
 #include "memory.h"
 #include "formats.h"
 #include "loader.h"
@@ -79,7 +78,7 @@ static char *conv_tolower, *conv_toupper;
 }
 
 #define POSITION { \
-	if ((pos = rules_length[(ARCH_INDEX)RULE]) == INVALID_LENGTH) { \
+	if ((pos = rules_length[ARCH_INDEX(RULE)]) == INVALID_LENGTH) { \
 		if (LAST) \
 			rules_errno = RULES_ERROR_POSITION; \
 		else \
@@ -90,15 +89,15 @@ static char *conv_tolower, *conv_toupper;
 
 #define CLASS(start, true, false) { \
 	if ((value = RULE) == '?') { \
-		if (!(class = rules_classes[(ARCH_INDEX)RULE])) { \
+		if (!(class = rules_classes[ARCH_INDEX(RULE)])) { \
 			if (LAST) \
 				rules_errno = RULES_ERROR_CLASS; \
 			else \
 				rules_errno = RULES_ERROR_END; \
 			return NULL; \
 		} \
-		for (pos = (start); (ARCH_INDEX)in[pos]; pos++) \
-		if (class[(ARCH_INDEX)in[pos]]) { \
+		for (pos = (start); ARCH_INDEX(in[pos]); pos++) \
+		if (class[ARCH_INDEX(in[pos])]) { \
 			true; \
 		} else { \
 			false; \
@@ -108,7 +107,7 @@ static char *conv_tolower, *conv_toupper;
 			rules_errno = RULES_ERROR_END; \
 			return NULL; \
 		} \
-		for (pos = (start); (ARCH_INDEX)in[pos]; pos++) \
+		for (pos = (start); ARCH_INDEX(in[pos]); pos++) \
 		if (in[pos] == value) { \
 			true; \
 		} else { \
@@ -123,30 +122,30 @@ static char *conv_tolower, *conv_toupper;
 }
 
 #define CONV(conv) { \
-	for (pos = 0; (out[pos] = (conv)[(ARCH_INDEX)in[pos]]); pos++); \
+	for (pos = 0; (out[pos] = (conv)[ARCH_INDEX(in[pos])]); pos++); \
 }
 
 static void rules_init_class(char name, char *valid)
 {
 	char *pos, inv;
 
-	rules_classes[(ARCH_INDEX)name] =
+	rules_classes[ARCH_INDEX(name)] =
 		mem_alloc_tiny(0x100, MEM_ALIGN_NONE);
-	memset(rules_classes[(ARCH_INDEX)name], 0, 0x100);
-	for (pos = valid; (ARCH_INDEX)*pos; pos++)
-		rules_classes[(ARCH_INDEX)name][(ARCH_INDEX)*pos] = 1;
+	memset(rules_classes[ARCH_INDEX(name)], 0, 0x100);
+	for (pos = valid; ARCH_INDEX(*pos); pos++)
+		rules_classes[ARCH_INDEX(name)][ARCH_INDEX(*pos)] = 1;
 
 	if (name >= 'a' && name <= 'z') {
 		inv = name & ~0x20;
-		rules_classes[(ARCH_INDEX)inv] =
+		rules_classes[ARCH_INDEX(inv)] =
 			mem_alloc_tiny(0x100, MEM_ALIGN_NONE);
-		memset(rules_classes[(ARCH_INDEX)inv], 1, 0x100);
-		for (pos = valid; (ARCH_INDEX)*pos; pos++)
-			rules_classes[(ARCH_INDEX)inv][(ARCH_INDEX)*pos] = 0;
+		memset(rules_classes[ARCH_INDEX(inv)], 1, 0x100);
+		for (pos = valid; ARCH_INDEX(*pos); pos++)
+			rules_classes[ARCH_INDEX(inv)][ARCH_INDEX(*pos)] = 0;
 	}
 }
 
-static void rules_init_classes()
+static void rules_init_classes(void)
 {
 	memset(rules_classes, 0, sizeof(rules_classes));
 
@@ -172,12 +171,12 @@ static char *rules_init_conv(char *src, char *dst)
 	for (pos = 0; pos < 0x100; pos++) conv[pos] = pos;
 
 	while (*src)
-		conv[(ARCH_INDEX)*src++] = *dst++;
+		conv[ARCH_INDEX(*src++)] = *dst++;
 
 	return conv;
 }
 
-static void rules_init_convs()
+static void rules_init_convs(void)
 {
 	conv_shift = rules_init_conv(conv_source, CONV_SHIFT);
 	conv_invert = rules_init_conv(conv_source, CONV_INVERT);
@@ -276,7 +275,7 @@ char *rules_apply(char *word, char *rule, int split)
 		in[RULE_WORD_SIZE - 1] = 0;
 
 		switch (LAST) {
-/* Crack v4.1 rules */
+/* Crack 4.1 rules */
 		case ':':
 		case ' ':
 		case '\t':
@@ -303,12 +302,12 @@ char *rules_apply(char *word, char *rule, int split)
 
 		case 'c':
 			pos = 0;
-			if ((out[0] = conv_toupper[(ARCH_INDEX)in[0]]))
+			if ((out[0] = conv_toupper[ARCH_INDEX(in[0])]))
 			while (in[++pos])
-				out[pos] = conv_tolower[(ARCH_INDEX)in[pos]];
+				out[pos] = conv_tolower[ARCH_INDEX(in[pos])];
 			out[pos] = 0;
 			if (out[0] == 'M' && out[1] == 'c')
-				out[2] = conv_toupper[(ARCH_INDEX)out[2]];
+				out[2] = conv_toupper[ARCH_INDEX(out[2])];
 			break;
 
 		case 'r':
@@ -426,7 +425,7 @@ char *rules_apply(char *word, char *rule, int split)
 			out = in;
 			break;
 
-/* Crack v5.0 rules */
+/* Crack 5.0 rules */
 		case '[':
 			if (in[0]) strcpy(out, &in[1]); else out[0] = 0;
 			break;
@@ -438,12 +437,12 @@ char *rules_apply(char *word, char *rule, int split)
 
 		case 'C':
 			pos = 0;
-			if ((out[0] = conv_tolower[(ARCH_INDEX)in[0]]))
+			if ((out[0] = conv_tolower[ARCH_INDEX(in[0])]))
 			while (in[++pos])
-				out[pos] = conv_toupper[(ARCH_INDEX)in[pos]];
+				out[pos] = conv_toupper[ARCH_INDEX(in[pos])];
 			out[pos] = 0;
 			if (out[0] == 'm' && out[1] == 'C')
-				out[2] = conv_tolower[(ARCH_INDEX)out[2]];
+				out[2] = conv_tolower[ARCH_INDEX(out[2])];
 			break;
 
 		case 't':
@@ -481,7 +480,7 @@ char *rules_apply(char *word, char *rule, int split)
 		case 'T':
 			POSITION
 			out = in;
-			out[pos] = conv_invert[(ARCH_INDEX)out[pos]];
+			out[pos] = conv_invert[ARCH_INDEX(out[pos])];
 			break;
 
 		case 'D':
@@ -677,7 +676,7 @@ int rules_count(struct rpp_context *start, int split)
 
 	if (!(count = rules_check(start, split))) {
 		fprintf(stderr, "Invalid rule in %s at line %d: %s\n",
-			path_expand(CFG_NAME), rules_line,
+			cfg_name, rules_line,
 			rules_errors[rules_errno]);
 		error();
 	}
