@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-2001 by Solar Designer
  */
 
 /*
@@ -19,28 +19,29 @@
  * to clear individual flags in a bitmask without a race condition on RISC,
  * or having to block the signals.
  */
-extern int event_pending;	/* An event is pending */
-extern int event_abort;		/* Abort requested */
-extern int event_save;		/* Time to save the crash recovery file */
-extern int event_status;	/* Status display requested */
+extern volatile int event_pending;	/* An event is pending */
+extern volatile int event_abort;	/* Abort requested */
+extern volatile int event_save;		/* Save the crash recovery file */
+extern volatile int event_status;	/* Status display requested */
 
 #if !OS_TIMER
 /*
  * Timer emulation for systems with no setitimer(2).
  */
 #include <sys/times.h>
+
 extern void sig_timer_emu_init(clock_t interval);
-extern void sig_timer_emu_tick();
+extern void sig_timer_emu_tick(void);
 #endif
 
 /*
  * Installs the signal handlers.
  */
-extern void sig_init(void (*yield)(int always));
+extern void sig_init(void);
 
 /*
  * Terminates the process if event_abort is set.
  */
-extern void check_abort();
+extern void check_abort(void);
 
 #endif
