@@ -1,6 +1,6 @@
 /*
  * This file is part of John the Ripper password cracker,
- * Copyright (c) 1996-98 by Solar Designer
+ * Copyright (c) 1996-99 by Solar Designer
  */
 
 #ifndef __DJGPP__
@@ -34,7 +34,7 @@ static int tty_fd = 0;
 static struct termios saved_ti;
 #endif
 
-void tty_init()
+void tty_init(void)
 {
 #ifndef __DJGPP__
 	int fd;
@@ -63,7 +63,7 @@ void tty_init()
 #endif
 }
 
-int tty_getchar()
+int tty_getchar(void)
 {
 #ifndef __DJGPP__
 	int c;
@@ -90,7 +90,7 @@ int tty_getchar()
 	return -1;
 }
 
-void tty_done()
+void tty_done(void)
 {
 #ifndef __DJGPP__
 	int fd;
